// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "inputcapture_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeInputCapture, "xdp-kde-inputcapture", QtInfoMsg)

