/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<appchooserdialog.h>)
#  include <appchooserdialog.h>
#endif
#if __has_include(<outputsmodel.h>)
#  include <outputsmodel.h>
#endif
#if __has_include(<wallpaper.h>)
#  include <wallpaper.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_xdgdesktopportal()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AppChooserData>("org.kde.xdgdesktopportal", 1);
    qmlRegisterTypesAndRevisions<AppFilterModel>("org.kde.xdgdesktopportal", 1);
    qmlRegisterTypesAndRevisions<OutputsModel>("org.kde.xdgdesktopportal", 1);
    qmlRegisterEnum<OutputsModel::Option>("OutputsModel::Option");
    qmlRegisterEnum<OutputsModel::Roles>("OutputsModel::Roles");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &WallpaperLocation::staticMetaObject;},
            "WallpaperLocation");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&WallpaperLocation::staticMetaObject, "org.kde.xdgdesktopportal", 1, nullptr, &WallpaperLocation::staticMetaObject, nullptr);
    qmlRegisterEnum<WallpaperLocation::Location>("WallpaperLocation::Location");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.xdgdesktopportal", 1, 0);
}

static const QQmlModuleRegistration orgkdexdgdesktopportalRegistration("org.kde.xdgdesktopportal", qml_register_types_org_kde_xdgdesktopportal);
