/****************************************************************************
** Meta object code from reading C++ file 'mobilefiledialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../xdg-desktop-portal-kde-6.7.4/src/kirigami-filepicker/api/mobilefiledialog.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mobilefiledialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16MobileFileDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto MobileFileDialog::qt_create_metaobjectdata<qt_meta_tag_ZN16MobileFileDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MobileFileDialog",
        "accepted",
        "",
        "QList<QUrl>",
        "files",
        "titleChanged",
        "selectMultipleChanged",
        "selectExistingChanged",
        "nameFiltersChanged",
        "mimeTypeFiltersChanged",
        "folderChanged",
        "currentFileChanged",
        "acceptLabelChanged",
        "selectFolderChanged",
        "cancel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accepted'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectMultipleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectExistingChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameFiltersChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mimeTypeFiltersChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentFileChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'acceptLabelChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectFolderChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cancel'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MobileFileDialog, qt_meta_tag_ZN16MobileFileDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MobileFileDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MobileFileDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MobileFileDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16MobileFileDialogE_t>.metaTypes,
    nullptr
} };

void MobileFileDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MobileFileDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accepted((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->selectMultipleChanged(); break;
        case 3: _t->selectExistingChanged(); break;
        case 4: _t->nameFiltersChanged(); break;
        case 5: _t->mimeTypeFiltersChanged(); break;
        case 6: _t->folderChanged(); break;
        case 7: _t->currentFileChanged(); break;
        case 8: _t->acceptLabelChanged(); break;
        case 9: _t->selectFolderChanged(); break;
        case 10: _t->cancel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)(const QList<QUrl> & )>(_a, &MobileFileDialog::accepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::selectMultipleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::selectExistingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::nameFiltersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::mimeTypeFiltersChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::folderChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::currentFileChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::acceptLabelChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::selectFolderChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobileFileDialog::*)()>(_a, &MobileFileDialog::cancel, 10))
            return;
    }
}

const QMetaObject *MobileFileDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MobileFileDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MobileFileDialogE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MobileFileDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void MobileFileDialog::accepted(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MobileFileDialog::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MobileFileDialog::selectMultipleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MobileFileDialog::selectExistingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MobileFileDialog::nameFiltersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MobileFileDialog::mimeTypeFiltersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MobileFileDialog::folderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MobileFileDialog::currentFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MobileFileDialog::acceptLabelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MobileFileDialog::selectFolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MobileFileDialog::cancel()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
