/****************************************************************************
** Meta object code from reading C++ file 'dirmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../xdg-desktop-portal-kde-6.7.4/src/kirigami-filepicker/declarative/dirmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dirmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8DirModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DirModel::qt_create_metaobjectdata<qt_meta_tag_ZN8DirModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DirModel",
        "folderChanged",
        "",
        "showDotFilesChanged",
        "isLoadingChanged",
        "nameFilterChanged",
        "mimeFiltersChanged",
        "lastErrorChanged",
        "folder",
        "QUrl",
        "showDotFiles",
        "isLoading",
        "nameFilter",
        "mimeFilters",
        "lastError",
        "Roles",
        "Name",
        "Url",
        "IconName",
        "IsDir",
        "IsLink",
        "FileSize",
        "MimeType",
        "IsHidden",
        "IsReadable",
        "IsWritable",
        "ModificationTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'folderChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showDotFilesChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isLoadingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameFilterChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mimeFiltersChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastErrorChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'folder'
        QtMocHelpers::PropertyData<QUrl>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'showDotFiles'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isLoading'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'nameFilter'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'mimeFilters'
        QtMocHelpers::PropertyData<QStringList>(13, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 4),
        // property 'lastError'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(15, 15, QMC::EnumFlags{}).add({
            {   16, Roles::Name },
            {   17, Roles::Url },
            {   18, Roles::IconName },
            {   19, Roles::IsDir },
            {   20, Roles::IsLink },
            {   21, Roles::FileSize },
            {   22, Roles::MimeType },
            {   23, Roles::IsHidden },
            {   24, Roles::IsReadable },
            {   25, Roles::IsWritable },
            {   26, Roles::ModificationTime },
        }),
    };
    return QtMocHelpers::metaObjectData<DirModel, qt_meta_tag_ZN8DirModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DirModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KDirSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DirModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DirModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8DirModelE_t>.metaTypes,
    nullptr
} };

void DirModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DirModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->folderChanged(); break;
        case 1: _t->showDotFilesChanged(); break;
        case 2: _t->isLoadingChanged(); break;
        case 3: _t->nameFilterChanged(); break;
        case 4: _t->mimeFiltersChanged(); break;
        case 5: _t->lastErrorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DirModel::*)()>(_a, &DirModel::folderChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirModel::*)()>(_a, &DirModel::showDotFilesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirModel::*)()>(_a, &DirModel::isLoadingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirModel::*)()>(_a, &DirModel::nameFilterChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirModel::*)()>(_a, &DirModel::mimeFiltersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DirModel::*)()>(_a, &DirModel::lastErrorChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->folder(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showDotFiles(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isLoading(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->nameFilter(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->mimeFilters(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->lastError(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFolder(*reinterpret_cast<QUrl*>(_v)); break;
        case 1: _t->setShowDotFiles(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setNameFilter(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setMimeFilters(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 4: _t->resetMimeFilters(); break;
        default: break;
        }
    }
}

const QMetaObject *DirModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DirModelE_t>.strings))
        return static_cast<void*>(this);
    return KDirSortFilterProxyModel::qt_metacast(_clname);
}

int DirModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDirSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DirModel::folderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DirModel::showDotFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DirModel::isLoadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DirModel::nameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DirModel::mimeFiltersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DirModel::lastErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
