/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.impl.portal.Session.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "sessionadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class SessionAdaptor
 */

SessionAdaptor::SessionAdaptor(Session *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

SessionAdaptor::~SessionAdaptor()
{
    // destructor
}

uint SessionAdaptor::version() const
{
    // get the value of property version
    return qvariant_cast< uint >(parent()->property("version"));
}

void SessionAdaptor::Close()
{
    // handle method call org.freedesktop.impl.portal.Session.Close
    parent()->Close();
}


#include "moc_sessionadaptor.cpp"
