/****************************************************************************
** Meta object code from reading C++ file 'inputcapture.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../xdg-desktop-portal-kde-6.7.4/src/inputcapture.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputcapture.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18InputCapturePortalE_t {};
} // unnamed namespace

template <> constexpr inline auto InputCapturePortal::qt_create_metaobjectdata<qt_meta_tag_ZN18InputCapturePortalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputCapturePortal",
        "D-Bus Interface",
        "org.freedesktop.impl.portal.InputCapture",
        "Disabled",
        "",
        "QDBusObjectPath",
        "session_handle",
        "QVariantMap",
        "options",
        "Activated",
        "Deactivated",
        "ZonesChanged",
        "CreateSession",
        "handle",
        "app_id",
        "parent_window",
        "QDBusMessage",
        "message",
        "uint&",
        "replyResponse",
        "QVariantMap&",
        "replyResults",
        "CreateSession2",
        "Start",
        "GetZones",
        "results",
        "SetPointerBarriers",
        "QList<QVariantMap>",
        "barriers",
        "zone_set",
        "Enable",
        "Disable",
        "Release",
        "ConnectToEIS",
        "QDBusUnixFileDescriptor",
        "version",
        "SupportedCapabilities"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Disabled'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QVariantMap &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'Activated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QVariantMap &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'Deactivated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QVariantMap &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'ZonesChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QVariantMap &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'CreateSession'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QString &, const QVariantMap &, const QDBusMessage &, uint &, QVariantMap &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 13 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
            { 0x80000000 | 7, 8 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'CreateSession2'
        QtMocHelpers::SlotData<QVariantMap(const QDBusObjectPath &, const QString &, const QVariantMap &)>(22, 4, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'Start'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QString &, const QVariantMap &, const QDBusMessage &, uint &, QVariantMap &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 13 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
            { 0x80000000 | 7, 8 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'GetZones'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(24, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 13 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 },
            { 0x80000000 | 20, 25 },
        }}),
        // Slot 'SetPointerBarriers'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, const QList<QVariantMap> &, uint, QVariantMap &)>(26, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 13 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 },
            { 0x80000000 | 27, 28 }, { QMetaType::UInt, 29 }, { 0x80000000 | 20, 25 },
        }}),
        // Slot 'Enable'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(30, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 20, 25 },
        }}),
        // Slot 'Disable'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(31, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 20, 25 },
        }}),
        // Slot 'Release'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(32, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 20, 25 },
        }}),
        // Slot 'ConnectToEIS'
        QtMocHelpers::SlotData<QDBusUnixFileDescriptor(const QDBusObjectPath &, const QString &, const QVariantMap &, const QDBusMessage &)>(33, 4, QMC::AccessPublic, 0x80000000 | 34, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 14 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(35, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'SupportedCapabilities'
        QtMocHelpers::PropertyData<uint>(36, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<InputCapturePortal, qt_meta_tag_ZN18InputCapturePortalE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InputCapturePortal::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InputCapturePortalE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InputCapturePortalE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18InputCapturePortalE_t>.metaTypes,
    nullptr
} };

void InputCapturePortal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputCapturePortal *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Disabled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 1: _t->Activated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 2: _t->Deactivated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 3: _t->ZonesChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 4: _t->CreateSession((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[8]))); break;
        case 5: { QVariantMap _r = _t->CreateSession2((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->Start((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[8]))); break;
        case 7: { uint _r = _t->GetZones((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 8: { uint _r = _t->SetPointerBarriers((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[7])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: { uint _r = _t->Enable((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 10: { uint _r = _t->Disable((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 11: { uint _r = _t->Release((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusUnixFileDescriptor _r = _t->ConnectToEIS((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputCapturePortal::*)(const QDBusObjectPath & , const QVariantMap & )>(_a, &InputCapturePortal::Disabled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputCapturePortal::*)(const QDBusObjectPath & , const QVariantMap & )>(_a, &InputCapturePortal::Activated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputCapturePortal::*)(const QDBusObjectPath & , const QVariantMap & )>(_a, &InputCapturePortal::Deactivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputCapturePortal::*)(const QDBusObjectPath & , const QVariantMap & )>(_a, &InputCapturePortal::ZonesChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->SupportedCapabilities(); break;
        default: break;
        }
    }
}

const QMetaObject *InputCapturePortal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputCapturePortal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18InputCapturePortalE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int InputCapturePortal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void InputCapturePortal::Disabled(const QDBusObjectPath & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void InputCapturePortal::Activated(const QDBusObjectPath & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void InputCapturePortal::Deactivated(const QDBusObjectPath & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void InputCapturePortal::ZonesChanged(const QDBusObjectPath & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN19InputCaptureSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto InputCaptureSession::qt_create_metaobjectdata<qt_meta_tag_ZN19InputCaptureSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputCaptureSession",
        "disabled",
        "",
        "activated",
        "activationId",
        "barrier",
        "QPointF",
        "cursorPosition",
        "deactivated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'disabled'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activated'
        QtMocHelpers::SignalData<void(uint, uint, const QPointF &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 }, { QMetaType::UInt, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'deactivated'
        QtMocHelpers::SignalData<void(uint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InputCaptureSession, qt_meta_tag_ZN19InputCaptureSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InputCaptureSession::staticMetaObject = { {
    QMetaObject::SuperData::link<Session::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19InputCaptureSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19InputCaptureSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19InputCaptureSessionE_t>.metaTypes,
    nullptr
} };

void InputCaptureSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputCaptureSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->disabled(); break;
        case 1: _t->activated((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[3]))); break;
        case 2: _t->deactivated((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputCaptureSession::*)()>(_a, &InputCaptureSession::disabled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputCaptureSession::*)(uint , uint , const QPointF & )>(_a, &InputCaptureSession::activated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputCaptureSession::*)(uint )>(_a, &InputCaptureSession::deactivated, 2))
            return;
    }
}

const QMetaObject *InputCaptureSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputCaptureSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19InputCaptureSessionE_t>.strings))
        return static_cast<void*>(this);
    return Session::qt_metacast(_clname);
}

int InputCaptureSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Session::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void InputCaptureSession::disabled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InputCaptureSession::activated(uint _t1, uint _t2, const QPointF & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void InputCaptureSession::deactivated(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
