/****************************************************************************
** Meta object code from reading C++ file 'globalshortcuts.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../xdg-desktop-portal-kde-6.7.4/src/globalshortcuts.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'globalshortcuts.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ShortcutInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto ShortcutInfo::qt_create_metaobjectdata<qt_meta_tag_ZN12ShortcutInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShortcutInfo",
        "id",
        "description",
        "keySequence",
        "QKeySequence"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'keySequence'
        QtMocHelpers::PropertyData<QKeySequence>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShortcutInfo, qt_meta_tag_ZN12ShortcutInfoE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShortcutInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ShortcutInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ShortcutInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ShortcutInfoE_t>.metaTypes,
    nullptr
} };

void ShortcutInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ShortcutInfo *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description; break;
        case 2: *reinterpret_cast<QKeySequence*>(_v) = _t->keySequence; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->id, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->description, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->keySequence, *reinterpret_cast<QKeySequence*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN22GlobalShortcutsSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto GlobalShortcutsSession::qt_create_metaobjectdata<qt_meta_tag_ZN22GlobalShortcutsSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GlobalShortcutsSession",
        "shortcutsChanged",
        "",
        "shortcutActivated",
        "shortcutName",
        "timestamp",
        "shortcutDeactivated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shortcutsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shortcutActivated'
        QtMocHelpers::SignalData<void(const QString &, qlonglong)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'shortcutDeactivated'
        QtMocHelpers::SignalData<void(const QString &, qlonglong)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::LongLong, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GlobalShortcutsSession, qt_meta_tag_ZN22GlobalShortcutsSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GlobalShortcutsSession::staticMetaObject = { {
    QMetaObject::SuperData::link<Session::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22GlobalShortcutsSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22GlobalShortcutsSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22GlobalShortcutsSessionE_t>.metaTypes,
    nullptr
} };

void GlobalShortcutsSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalShortcutsSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shortcutsChanged(); break;
        case 1: _t->shortcutActivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 2: _t->shortcutDeactivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcutsSession::*)()>(_a, &GlobalShortcutsSession::shortcutsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcutsSession::*)(const QString & , qlonglong )>(_a, &GlobalShortcutsSession::shortcutActivated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcutsSession::*)(const QString & , qlonglong )>(_a, &GlobalShortcutsSession::shortcutDeactivated, 2))
            return;
    }
}

const QMetaObject *GlobalShortcutsSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GlobalShortcutsSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22GlobalShortcutsSessionE_t>.strings))
        return static_cast<void*>(this);
    return Session::qt_metacast(_clname);
}

int GlobalShortcutsSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Session::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void GlobalShortcutsSession::shortcutsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GlobalShortcutsSession::shortcutActivated(const QString & _t1, qlonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void GlobalShortcutsSession::shortcutDeactivated(const QString & _t1, qlonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN21GlobalShortcutsPortalE_t {};
} // unnamed namespace

template <> constexpr inline auto GlobalShortcutsPortal::qt_create_metaobjectdata<qt_meta_tag_ZN21GlobalShortcutsPortalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GlobalShortcutsPortal",
        "D-Bus Interface",
        "org.freedesktop.impl.portal.GlobalShortcuts",
        "Activated",
        "",
        "QDBusObjectPath",
        "session_handle",
        "shortcutId",
        "timestamp",
        "QVariantMap",
        "unused",
        "Deactivated",
        "ShortcutsChanged",
        "Shortcuts",
        "shortcuts",
        "BindShortcuts",
        "handle",
        "parent_window",
        "options",
        "QDBusMessage",
        "message",
        "uint&",
        "replyResponse",
        "QVariantMap&",
        "replyResults",
        "CreateSession",
        "app_id",
        "results",
        "ListShortcuts",
        "ConfigureShortcuts",
        "version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Activated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &, quint64, const QVariantMap &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 }, { QMetaType::ULongLong, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'Activated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &, quint64)>(3, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 }, { QMetaType::ULongLong, 8 },
        }}),
        // Signal 'Deactivated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &, quint64, const QVariantMap &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 }, { QMetaType::ULongLong, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'Deactivated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QString &, quint64)>(11, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 7 }, { QMetaType::ULongLong, 8 },
        }}),
        // Signal 'ShortcutsChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const Shortcuts &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'BindShortcuts'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &, const Shortcuts &, const QString &, const QVariantMap &, const QDBusMessage &, uint &, QVariantMap &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 16 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 13, 14 }, { QMetaType::QString, 17 },
            { 0x80000000 | 9, 18 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'CreateSession'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(25, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 16 }, { 0x80000000 | 5, 6 }, { QMetaType::QString, 26 }, { 0x80000000 | 9, 18 },
            { 0x80000000 | 23, 27 },
        }}),
        // Slot 'ListShortcuts'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, QVariantMap &)>(28, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 16 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 23, 27 },
        }}),
        // Slot 'ConfigureShortcuts'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QString &, const QVariantMap &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 17 }, { 0x80000000 | 9, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(30, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GlobalShortcutsPortal, qt_meta_tag_ZN21GlobalShortcutsPortalE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject GlobalShortcutsPortal::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GlobalShortcutsPortalE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GlobalShortcutsPortalE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21GlobalShortcutsPortalE_t>.metaTypes,
    nullptr
} };

void GlobalShortcutsPortal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GlobalShortcutsPortal *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Activated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4]))); break;
        case 1: _t->Activated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3]))); break;
        case 2: _t->Deactivated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4]))); break;
        case 3: _t->Deactivated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[3]))); break;
        case 4: _t->ShortcutsChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Shortcuts>>(_a[2]))); break;
        case 5: _t->BindShortcuts((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Shortcuts>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[8]))); break;
        case 6: { uint _r = _t->CreateSession((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 7: { uint _r = _t->ListShortcuts((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->ConfigureShortcuts((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Shortcuts >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Shortcuts >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcutsPortal::*)(const QDBusObjectPath & , const QString & , quint64 , const QVariantMap & )>(_a, &GlobalShortcutsPortal::Activated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcutsPortal::*)(const QDBusObjectPath & , const QString & , quint64 , const QVariantMap & )>(_a, &GlobalShortcutsPortal::Deactivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GlobalShortcutsPortal::*)(const QDBusObjectPath & , const Shortcuts & )>(_a, &GlobalShortcutsPortal::ShortcutsChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *GlobalShortcutsPortal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GlobalShortcutsPortal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GlobalShortcutsPortalE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int GlobalShortcutsPortal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void GlobalShortcutsPortal::Activated(const QDBusObjectPath & _t1, const QString & _t2, quint64 _t3, const QVariantMap & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void GlobalShortcutsPortal::Deactivated(const QDBusObjectPath & _t1, const QString & _t2, quint64 _t3, const QVariantMap & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void GlobalShortcutsPortal::ShortcutsChanged(const QDBusObjectPath & _t1, const Shortcuts & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
