// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "dynamiclauncher_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeDynamicLauncher, "xdp-kde-dynamic-launcher", QtInfoMsg)

