// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "accessdialog_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeAccessDialog, "xdp-kde-access-dialog", QtInfoMsg)

