// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "desktopportal_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeDesktopPortal, "xdp-kde-desktop-portal", QtInfoMsg)

