/****************************************************************************
** Meta object code from reading C++ file 'remotedesktop.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../xdg-desktop-portal-kde-6.7.4/src/remotedesktop.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'remotedesktop.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19RemoteDesktopPortalE_t {};
} // unnamed namespace

template <> constexpr inline auto RemoteDesktopPortal::qt_create_metaobjectdata<qt_meta_tag_ZN19RemoteDesktopPortalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RemoteDesktopPortal",
        "D-Bus Interface",
        "org.freedesktop.impl.portal.RemoteDesktop",
        "CreateSession",
        "",
        "QDBusObjectPath",
        "handle",
        "session_handle",
        "app_id",
        "QVariantMap",
        "options",
        "QVariantMap&",
        "results",
        "SelectDevices",
        "Start",
        "parent_window",
        "QDBusMessage",
        "message",
        "uint&",
        "replyResponse",
        "replyResults",
        "NotifyPointerMotion",
        "dx",
        "dy",
        "NotifyPointerMotionAbsolute",
        "stream",
        "x",
        "y",
        "NotifyPointerButton",
        "button",
        "state",
        "NotifyPointerAxis",
        "NotifyPointerAxisDiscrete",
        "axis",
        "steps",
        "NotifyKeyboardKeycode",
        "keycode",
        "NotifyKeyboardKeysym",
        "keysym",
        "NotifyTouchDown",
        "slot",
        "NotifyTouchMotion",
        "NotifyTouchUp",
        "ConnectToEIS",
        "QDBusUnixFileDescriptor",
        "version",
        "AvailableDeviceTypes"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CreateSession'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(3, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'SelectDevices'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(13, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'Start'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QString &, const QVariantMap &, const QDBusMessage &, uint &, QVariantMap &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 15 },
            { 0x80000000 | 9, 10 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 11, 20 },
        }}),
        // Slot 'NotifyPointerMotion'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, double, double)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::Double, 22 }, { QMetaType::Double, 23 },
        }}),
        // Slot 'NotifyPointerMotionAbsolute'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, uint, double, double)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::UInt, 25 }, { QMetaType::Double, 26 },
            { QMetaType::Double, 27 },
        }}),
        // Slot 'NotifyPointerButton'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, int, uint)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::Int, 29 }, { QMetaType::UInt, 30 },
        }}),
        // Slot 'NotifyPointerAxis'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, double, double)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::Double, 22 }, { QMetaType::Double, 23 },
        }}),
        // Slot 'NotifyPointerAxisDiscrete'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, uint, int)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::UInt, 33 }, { QMetaType::Int, 34 },
        }}),
        // Slot 'NotifyKeyboardKeycode'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, int, uint)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::Int, 36 }, { QMetaType::UInt, 30 },
        }}),
        // Slot 'NotifyKeyboardKeysym'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, int, uint)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::Int, 38 }, { QMetaType::UInt, 30 },
        }}),
        // Slot 'NotifyTouchDown'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, uint, uint, double, double)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::UInt, 25 }, { QMetaType::UInt, 40 },
            { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Slot 'NotifyTouchMotion'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, uint, uint, double, double)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::UInt, 25 }, { QMetaType::UInt, 40 },
            { QMetaType::Double, 26 }, { QMetaType::Double, 27 },
        }}),
        // Slot 'NotifyTouchUp'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QVariantMap &, uint)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 7 }, { 0x80000000 | 9, 10 }, { QMetaType::UInt, 40 },
        }}),
        // Slot 'ConnectToEIS'
        QtMocHelpers::SlotData<QDBusUnixFileDescriptor(const QDBusObjectPath &, const QString &, const QVariantMap &, const QDBusMessage &)>(43, 4, QMC::AccessPublic, 0x80000000 | 44, {{
            { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(45, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'AvailableDeviceTypes'
        QtMocHelpers::PropertyData<uint>(46, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RemoteDesktopPortal, qt_meta_tag_ZN19RemoteDesktopPortalE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RemoteDesktopPortal::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RemoteDesktopPortalE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RemoteDesktopPortalE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19RemoteDesktopPortalE_t>.metaTypes,
    nullptr
} };

void RemoteDesktopPortal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RemoteDesktopPortal *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { uint _r = _t->CreateSession((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 1: { uint _r = _t->SelectDevices((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->Start((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[8]))); break;
        case 3: _t->NotifyPointerMotion((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 4: _t->NotifyPointerMotionAbsolute((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5]))); break;
        case 5: _t->NotifyPointerButton((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 6: _t->NotifyPointerAxis((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 7: _t->NotifyPointerAxisDiscrete((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 8: _t->NotifyKeyboardKeycode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 9: _t->NotifyKeyboardKeysym((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4]))); break;
        case 10: _t->NotifyTouchDown((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6]))); break;
        case 11: _t->NotifyTouchMotion((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6]))); break;
        case 12: _t->NotifyTouchUp((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 13: { QDBusUnixFileDescriptor _r = _t->ConnectToEIS((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusUnixFileDescriptor*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->AvailableDeviceTypes(); break;
        default: break;
        }
    }
}

const QMetaObject *RemoteDesktopPortal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoteDesktopPortal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RemoteDesktopPortalE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int RemoteDesktopPortal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN20RemoteDesktopSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto RemoteDesktopSession::qt_create_metaobjectdata<qt_meta_tag_ZN20RemoteDesktopSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RemoteDesktopSession"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RemoteDesktopSession, qt_meta_tag_ZN20RemoteDesktopSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RemoteDesktopSession::staticMetaObject = { {
    QMetaObject::SuperData::link<ScreenCastSession::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20RemoteDesktopSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20RemoteDesktopSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20RemoteDesktopSessionE_t>.metaTypes,
    nullptr
} };

void RemoteDesktopSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RemoteDesktopSession *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *RemoteDesktopSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemoteDesktopSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20RemoteDesktopSessionE_t>.strings))
        return static_cast<void*>(this);
    return ScreenCastSession::qt_metacast(_clname);
}

int RemoteDesktopSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScreenCastSession::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
