// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "waylandintegration_debug.h"


Q_LOGGING_CATEGORY(XdgDesktopPortalKdeWaylandIntegration, "xdp-kde-wayland-integration", QtInfoMsg)

